package Task::BeLike::XAERXESS;

use strict;
use 5.008_005;
our $VERSION = '0.001';

1;
__END__

=encoding utf-8

=head1 NAME

Task::BeLike::XAERXESS - Just few modules I use, or like, or both.

=head1 SYNOPSIS

  $ cpan Task::BeLike::XAERXESS

=head1 DESCRIPTION

This L<Task> module installs modules I use frequently.

=head1 AUTHOR

Grzegorz Rożniecki E<lt>xaerxess@gmail.comE<gt>

=head1 COPYRIGHT

Copyright 2014- Grzegorz Rożniecki

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

L<Task>

=cut
